=============
API Tutorials
=============

We have several API tutorials below to demonstrate how to use various features
of the Aydin API provides. You can also try each of them on [Google Colab platform]().

.. toctree::
   :maxdepth: 1
   :caption: Restoration

   Denoise an image using Classic <api_tutorials/restoration/classic>
   Denoise an image using Noise2SelfFGR <api_tutorials/restoration/noise2self_fgr>
   Denoise an image using Noise2SelfCNN <api_tutorials/restoration/noise2self_cnn>
   Deconvolving an image using aydin API <api_tutorials/restoration/lucyrichardson>


.. toctree::
   :maxdepth: 1
   :caption: Image Translator

   Denoise an image using ImageDenoiserClassic <api_tutorials/image_translator/classic>
   Denoise an image using ImageTranslatorFGR <api_tutorials/image_translator/fgr>
   Denoise an image using ImageTranslatorCNN  <api_tutorials/image_translator/cnn>
   How to implement Noise2Noise using ImageTranslatorFGR <api_tutorials/image_translator/noise2noise>
   How to implement supervised denoising using image translators <api_tutorials/image_translator/supervised>

.. toctree::
   :maxdepth: 1
   :caption: Transforms

   Apply attenuation transform <api_tutorials/transforms/attenuation>
   Apply deskew transform <api_tutorials/transforms/deskew>
   Apply fixed pattern transform <api_tutorials/transforms/fixed_pattern>
   Apply high-pass transform <api_tutorials/transforms/highpass>
   Apply histogram equalisation transform <api_tutorials/transforms/histogram>
   Apply motion stabilisation transform <api_tutorials/transforms/motion>
   Apply padding transform <api_tutorials/transforms/padding>
   Apply periodic noise suppression transform <api_tutorials/transforms/periodic>
   Apply range transform <api_tutorials/transforms/range>
   Apply salt-pepper transform <api_tutorials/transforms/salt_pepper>
   Apply variance stabilisation transform <api_tutorials/transforms/variance_stabilisation>
